Learn R Programming

RClimacell (version 0.1.4)

dict_moonphase: Moonphase Dictionary

Description

this is a helper function that returns the moon phase tibble containing the moon phase codes (which are returned by Climacell API) and their appropriate description.

Usage

dict_moonphase()

Arguments

Value

a tibble