Learn R Programming

RClimacell (version 0.1.4)

dict_preciptype: Precipitation Type Dictionary

Description

this is a helper function that returns the precipitation type tibble containing the precipitation type codes (which are returned by Climacell API) and their appropriate description.

Usage

dict_preciptype()

Arguments

Value

a tibble